from fastapi import APIRouter, Depends
from sqlalchemy.orm import Session
from app.db.session import get_db

router = APIRouter()


@router.get("/health")
def health_check(db: Session = Depends(get_db)):
    """
    Health check endpoint for the API.
    Returns status of the API and database connectivity.
    """
    # Check database connection
    try:
        # Execute a simple query to verify database connectivity
        db.execute("SELECT 1")
        db_status = "healthy"
    except Exception as e:
        db_status = f"unhealthy: {str(e)}"

    return {"status": "healthy", "database": db_status, "version": "1.0.0"}
